function out = equation_1(delta,T)
  
  %  This function calculates the ratio of KDP/Z0
  %
  %  Calculations are according to Myagkov et al. 2020 (AMTD)
  %  "Evaluation of the reflectivity calibration of W-band radars based on
  %  observations in rain".
  %  Coefficients are taken from Table A1, the output correspond to Eq. 1.
  %
  %  Input parameters:
  %
  %  delta: backscattering phase shift in deg. It must be from 0 to 4.5.
  %  T: temperature in deg C. 
  %  T must be one of the following values 0, 10, 20, 30.
  %
  %  Output parameters:
  %
  %  out: ratio KDP/Z0 in deg/km * m^3/mm^6
  %
  %  Example:
  %
  %  plot(0:0.1:4.5,equation_1(0:0.1:4.5,0))
  %  hold on
  %  plot(0:0.1:4.5,equation_1(0:0.1:4.5,10))
  %  plot(0:0.1:4.5,equation_1(0:0.1:4.5,20))
  %  plot(0:0.1:4.5,equation_1(0:0.1:4.5,30))
  %  grid on
  %  xlabel('Backscattering phase shift [^\circ]')
  %  ylabel('KDP/Z0 [^\circ km^{-1} mm^{-6} m^3]')
  %  legend('0 ^\circ C','10 ^\circ C','20 ^\circ C','30 ^\circ C')
  %
  %  This code has been tested in Octave versions 4.4.0 and 5.1.0, 
  %  and in Matlab r2014b
  %
  %  Author:  Dr. Alexander Myagkov, Radiometer Physics GmbH
  %  Contact: alexander.myagkov@radiometer-physics.de
  
  if length(T) > 1 | length(T) == 0
    error('Parameter T must be a scalar')
  end
  
  switch T
    
    case 0
    
      a1  = 1.2009;
      a2  = 0.57645;
      a3  = -0.63757;
      a4  = 1.1668;
      a5  = -0.58585;
      a6  = 0.65202;
      a7  = 1.1906;
      a8  = -1.2823*10^(-2);
      a9  = 0.21614;
      a10 = -0.24463;  
  
    case 10
      
      a1  = -1.1258;
      a2  = 0.40592;
      a3  = -0.29526;
      a4  = 1.7753;
      a5  = 0.47124;
      a6  = -0.39622;
      a7  = 0.70655;
      a8  = -0.54765;
      a9  = 0.51483;
      a10 = 1.2125*10^(-2);
      
    case 20
      
      a1  = -2.8779;
      a2  = -3.3353;
      a3  = -3.9686;
      a4  = 6.1885*10^(-4);
      a5  = 5.6427;
      a6  = -2.9301;
      a7  = 3.1233;
      a8  = -1.4422*10^(-2);
      a9  = -1.6498;
      a10 = 2.6475*10^(-2);
      
    case 30
      
      a1  = -1.8256;
      a2  = 3.9987*10^(-3);
      a3  = -0.46699;
      a4  = -3.0455;
      a5  = -1.2881;
      a6  = 1.2233;
      a7  = -3.0428;
      a8  = 1.2892;
      a9  = -1.2249;
      a10 = -0.79335;
      
    otherwise
      
      error('Temperature must be one of the following values 0,10,20,30 deg C.')
      
  end
  
  if length(delta) == 0
    error('delta is not specified')
  end
  
  if sum(delta < 0 | delta > 4.5) > 0
    error('Delta must be in the range from 0 to 4.5 deg.')
  end  
  
  x1 = a2.*delta +a3;
  x2 = a5.*delta +a6;
  x3 = a8.*delta +a9;
  
  f1 = 2./(1+exp(-2*x1))-1;
  f2 = 2./(1+exp(-2*x2))-1;
  f3 = 2./(1+exp(-2*x3))-1;
  
  out = a1.*f1+a4.*f2+a7.*f3+a10;
  
end