function out = equation_3(delta,z,T)
  
  %  This function calculates the ratio of KDP/Z0
  %
  %  Calculations are according to Myagkov et al. 2020 (AMTD)
  %  "Evaluation of the reflectivity calibration of W-band radars based on
  %  observations in rain".
  %  Coefficients are taken from Table A3, the output correspond to Eq. 3.
  %
  %  Input parameters:
  %
  %  delta: backscattering phase shift in deg. It must be from 0 to 4.5.
  %  z: non-attenuated reflectivity in mm^6/m^3. 
  %  Values of z should be from 10 to 500.
  %
  %  NOTE: Length of vectors delta and z must be the same!
  %
  %  T: temperature in deg C. 
  %  T must be one of the following values 0, 10, 20, 30.
  %
  %  Output parameters:
  %
  %  out: A in dB/km
  %
  %  Example:
  %
  %  delta = linspace(0,1,20);
  %  z     = 10.^(linspace(10,27,20)/10);
  %
  %  plot(10*log10(z),equation_3(delta,z,0))
  %  hold on
  %  plot(10*log10(z),equation_3(delta,z,10))
  %  plot(10*log10(z),equation_3(delta,z,20))
  %  plot(10*log10(z),equation_3(delta,z,30))
  %  grid on
  %  xlabel('Non-attenuated reflectivity [dBZ]')
  %  ylabel('Specific attenuation A [dB/km]')
  %  legend('0 ^\circ C','10 ^\circ C','20 ^\circ C','30 ^\circ C')
  %
  %  This code has been tested in Octave versions 4.4.0 and 5.1.0, 
  %  and in Matlab r2014b
  %
  %  Author:  Dr. Alexander Myagkov, Radiometer Physics GmbH
  %  Contact: alexander.myagkov@radiometer-physics.de
  
  if length(T) > 1 | length(T) == 0
    error('Parameter T must be a scalar')
  end
  
  switch T
    
    case 0
    
      c1 = 40.205;
      c2 = -7.0826*10^(-2);
      c3 = -2.3107;
      c4 = -0.57936;
      c5 = 97.864;
      c6 = -0.92476;
      c7 = -8.579*10^(-4);
      c8 = 0.57887;
      c9 = -89.12;
      c10 = -8.2716*10^(-3);
      c11 = -7.8008*10^(-4);
      c12 = -0.31605;
      c13 = -96.211;
      c14 = -0.93417;
      c15 = -4.8612*10^(-4);
      c16 = 0.58409;
      c17 = 12.477; 
  
    case 10
      
      c1 = 219.03;
      c2 = 0.23509;
      c3 = 4.7215*10^(-5);
      c4 = -0.33685;
      c5 = 135.85;
      c6 = -0.24005;
      c7 = 8.2907*10^(-4);
      c8 = 0.42938;
      c9 = -84.345;
      c10 = 0.2336;
      c11 = 1.0573*10^(-3);
      c12 = -0.14118;
      c13 = 9.2789;
      c14 = -8.079*10^(-2);
      c15 = -2.2057;
      c16 = -0.51589;
      c17 = 13.823;
      
    case 20
      
      c1 = -59.016;
      c2 = 5.1985*10^(-2);
      c3 = 2.3352;
      c4 = 0.58912;
      c5 = -194.27;
      c6 = 0.22257;
      c7 = -6.3754*10^(-4);
      c8 = -0.40174;
      c9 = 331.89;
      c10 = 0.21176;
      c11 = 5.3636*10^(-5);
      c12 = -0.30519;
      c13 = -142.34;
      c14 = 0.19708;
      c15 = 7.7241*10^(-4);
      c16 = -0.1073;
      c17 = 68.223;
      
    case 30
      
      c1 = 284.28;
      c2 = 0.20864;
      c3 = 8.242*10^(-5);
      c4 = -0.3047;
      c5 = 130.09;
      c6 = -0.18727;
      c7 = -7.8938*10^(-4);
      c8 = 8.4885*10^(-2);
      c9 = 160.48;
      c10 = -0.22374;
      c11 = 6.816*10^(-4);
      c12 = 0.4095;
      c13 = 96.122;
      c14 = -5.9172*10^(-2);
      c15 = -2.2104;
      c16 = -0.51291;
      c17 = 107.13;
      
    otherwise
      
      error('Temperature must be one of the following values 0,10,20,30 deg C.')
      
  end
  
  if length(delta) == 0
    error('delta is not specified')
  end
  
  if length(z) == 0
    error('z is not specified')
  end
  
  if length(delta) ~= length(z)
    error('Length of vectors delta and z must be the same.')
  end
  
  if sum(delta < 0 | delta > 4.5) > 0
    error('Delta must be in the range from 0 to 4.5 deg.')
  end  
  
  x1 = c2.*delta + c3.*z + c4;
  x2 = c6.*delta + c7.*z + c8;
  x3 = c10.*delta + c11.*z + c12;
  x4 = c14.*delta + c15.*z + c16;
  
  f1 = 2./(1+exp(-2*x1))-1;
  f2 = 2./(1+exp(-2*x2))-1;
  f3 = 2./(1+exp(-2*x3))-1;
  f4 = 2./(1+exp(-2*x4))-1;
  
  out = c1.*f1 + c5.*f2 + c9.*f3 + c13.*f4 + c17;
  
end