function out = equation_A6(d,T,rh)
  
  %  This function calculates the size of a droplet at 250 m for a given
  %  size observed at the surface.
  %
  %  Calculations are according to Myagkov et al. 2020 (AMTD)
  %  "Evaluation of the reflectivity calibration of W-band radars based on
  %  observations in rain".
  %  Coefficients are taken from Table A4, the output correspond to Eq. A6.
  %
  %  The atmospheric state model assumes the lapse rate of 4:8x10^-3 K/m and
  %  constant profile of relative humidity (rh).
  %
  %  Input parameters:
  %
  %  d: equivolumetric diameter [mm] of a droplet observed at the surface.
  %  d can be a scalar or a vector.
  %  T: surface temperature in deg C. T must be a scalar. 
  %  T must be from 0 to 30.
  %  rh: surface relative humidity in %, must be from 60 to 100 %.
  %  rh must be a scalar.
  %
  %  Output parameters:
  %
  %  out: equivolumetric diameter [mm] of the droplet at 250 m corrected for
  %       evaporation.
  %
  %  Example:
  %
  %  plot(0.1:0.1:3,equation_A6(0.1:0.1:3,30,100))
  %  hold on
  %  plot(0.1:0.1:3,equation_A6(0.1:0.1:3,30,90))
  %  plot(0.1:0.1:3,equation_A6(0.1:0.1:3,30,80))
  %  plot(0.1:0.1:3,equation_A6(0.1:0.1:3,30,60))
  %  grid on
  %  xlabel('Equivolumetric diameter at surface [mm]')
  %  ylabel('Equivolumetric diameter at 250 m [mm], T = 30^\circ')
  %  legend('100 %','90 %','80 %','60 %')
  %
  %  This code has been tested in Octave versions 4.4.0 and 5.1.0, 
  %  and in Matlab r2014b
  %
  %  Author:  Dr. Alexander Myagkov, Radiometer Physics GmbH
  %  Contact: alexander.myagkov@radiometer-physics.de
  
  if length(T) > 1
    error('T must be a scalar')
  end
  
  if T < 0 | T > 30
    error('T must be in the range from 0 to 30 deg C.')
  end
  
  if length(rh) > 1
    error('rh must be a scalar')
  end
  
  if rh < 60 | rh > 100
    error('rh must be in the range from 60 to 100 %.')
  end
  
  if sum(d <= 0)
    error('Values of d must exceed 0 mm')
  end
  
  g1 = -20.127;
  g2 = 20.19;
  g3 = -19.996;
  g4 = -20.054;
  g5 = -20.176;
  g6 = -19.919;
  g7 = 24.614;
  g8 = 20.019;
  g9 = 19.928;
  g10 = -24.296;

  p1 = 0.68097;
  p2 = -0.51637;
  p3 = 2.8944*10^(-2);
  p4 = -0.1005;
  p5 = 6.129*10^3;
  p6 = -0.72646;
  p7 = 4.5325*10^4;
  p8 = -4.0408*10^(-2);
  p9 = 0.32405;
  p10 = -1.6549*10^4;

  q1 = -2.4517*10^(-3);
  q2 = 1.6484*10^(-3);
  q3 = -1.3688*10^(-3);
  q4 = 1.5558*10^(-3);
  q5 = 1.3961*10^3;
  q6 = 2.2635*10^(-3);
  q7 = 5.0256*10^3;
  q8 = 1.0534*10^(-3);
  q9 = -1.8539*10^(-3);
  q10 = -1.6845*10^3;

  u1 = -7.2329*10^(-3);
  u2 = -1.0423*10^(-3);
  u3 = -9.1852*10^(-3);
  u4 = 8.7377*10^(-3);
  u5 = -3.2785*10^4;
  u6 = 4.6927*10^(-3);
  u7 = -6.6315*10^3;
  u8 = 5.0666*10^(-3);
  u9 = -6.4004*10^(-3);
  u10 = 1.6804*10^3;

  alpha_1 = 0.86151;
  alpha_2 = -0.84634;
  alpha_3 = -0.7242;
  alpha_4 = 0.26384;
  alpha_5 = -3.3515*10^2;
  alpha_6 = -0.62472;
  alpha_7 = 1.0859*10^4;
  alpha_8 = 9.138*10^(-2);
  alpha_9 = 1.2194;
  alpha_10 = 1.8939*10^4;
  
  beta = 20.038;
  
  x1  = p1.*d  + q1.*T  + u1.*rh  + alpha_1;
  x2  = p2.*d  + q2.*T  + u2.*rh  + alpha_2;
  x3  = p3.*d  + q3.*T  + u3.*rh  + alpha_3;
  x4  = p4.*d  + q4.*T  + u4.*rh  + alpha_4;
  x5  = p5.*d  + q5.*T  + u5.*rh  + alpha_5;
  x6  = p6.*d  + q6.*T  + u6.*rh  + alpha_6;
  x7  = p7.*d  + q7.*T  + u7.*rh  + alpha_7;
  x8  = p8.*d  + q8.*T  + u8.*rh  + alpha_8;
  x9  = p9.*d  + q9.*T  + u9.*rh  + alpha_9;
  x10 = p10.*d + q10.*T + u10.*rh + alpha_10;
  
  f1 = 2./(1+exp(-2*x1))-1;
  f2 = 2./(1+exp(-2*x2))-1;
  f3 = 2./(1+exp(-2*x3))-1;
  f4 = 2./(1+exp(-2*x4))-1;
  f5 = 2./(1+exp(-2*x5))-1;
  f6 = 2./(1+exp(-2*x6))-1;
  f7 = 2./(1+exp(-2*x7))-1;
  f8 = 2./(1+exp(-2*x8))-1;
  f9 = 2./(1+exp(-2*x9))-1;
  f10 = 2./(1+exp(-2*x10))-1;
  
  out = g1.*f1+g2.*f2+g3.*f3+g4.*f4+g5.*f5+g6.*f6+g7.*f7+...
        g8.*f8+g9.*f9+g10.*f10+beta;
        
  out(d >= 3) = d(d >= 3);
  
end